# Credits

## Development Team

* Andres Ladino <andres.ladino@univ-eiffel.fr>
* Cecile Becarie <cecile.becarie@univ-eiffel.fr>
* Florian Gacon <florian.gacon@univ-eiffel.fr>

## Contributors

None yet. Why not be the first?
